.. include:: ../README.rst


.. toctree::
   :maxdepth: 1
   :caption: User Guide

   API Documentation <api/pysindy>
   Examples <examples/index>
   Practical tips <tips>

.. toctree::
   :maxdepth: 1
   :caption: Useful links


   PySINDy @ PyPI <https://pypi.org/project/PySINDy/>
   Issue Tracker <https://github.com/dynamicslab/pysindy/issues>
